@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package main
 
@@ -1375,7 +1362,31 @@ func (m *Manager) HandleSystemEvent(sender dbus.Sender, eventType string) *dbus.
 }
 
 func (m *Manager) handleAutoCheckEvent() error {
+	var checkNeedUpdateSource = func() bool {
+		upgradeTypeList := []string{
+			system.PrepareDistUpgradeJobType,
+			system.PrepareSystemUpgradeJobType,
+			system.PrepareAppStoreUpgradeJobType,
+			system.PrepareUnknownUpgradeJobType,
+			system.PrepareSecurityUpgradeJobType,
+			system.DistUpgradeJobType,
+			system.SystemUpgradeJobType,
+			system.AppStoreUpgradeJobType,
+			system.SecurityUpgradeJobType,
+			system.UnknownUpgradeJobType,
+		}
+		for _, job := range m.jobList {
+			if job.Status == system.RunningStatus && strv.Strv(upgradeTypeList).Contains(job.Type) {
+				return false
+			}
+		}
+		return true
+	}
 	if m.config.AutoCheckUpdates {
+		if !checkNeedUpdateSource() {
+			logger.Info("lastore is running prepare upgrade or upgrade job, not need check update")
+			return nil
+		}
 		_, err := m.updateSource(m.updater.UpdateNotify, true)
 		if err != nil {
 			logger.Warning(err)
@@ -1639,6 +1650,7 @@ func (m *Manager) getLastoreSystemUnitMap() lastoreUnitMap {
 	}
 	unitMap["watchUpdateInfo"] = []string{
 		"--path-property=PathModified=/var/lib/lastore/update_infos.json",
+		"--property=StartLimitBurst=0",
 		"/bin/bash",
 		"-c",
 		fmt.Sprintf(`%s string:"%s"`, lastoreDBusCmd, "UpdateInfosChanged"), //监听update_infos.json文件
